# Contributing to SDR-RPC

Thank you for considering contributing to **SDR-RPC**! Your input, feedback, and contributions help make this project better for everyone. Whether you're submitting a bug report, suggesting a new feature, or contributing code, this guide will help you get started.

---

## How Can You Contribute?

### Reporting Bugs
If you find a bug, please help us by reporting it. When creating a bug report, provide as much detail as possible to make it easier for us to investigate and resolve the issue.

#### Steps for Reporting Bugs:
1. Check the [issues page](https://github.com/EnderIce2/SDR-RPC/issues) to see if the bug has already been reported.
2. If not, create a new issue and include:
   - A clear and descriptive title.
   - Steps to reproduce the issue.
   - Your system configuration (OS version, SDRSharp version, etc.).
   - Any error logs or screenshots that might help.

---

### Suggesting Features or Enhancements
Have an idea to improve SDR-RPC? We’d love to hear it!

#### Steps for Suggesting Features:
1. Check the [issues page](https://github.com/EnderIce2/SDR-RPC/issues) to ensure the feature hasn't already been requested.
2. Create a new issue and include:
   - A clear description of the feature or enhancement.
   - Why this feature would be useful.
   - Any relevant examples or references.

---

### Contributing Code
We welcome pull requests for bug fixes, features, or documentation improvements.

#### Steps for Code Contributions:
1. **Fork the Repository**  
   - Navigate to the project repository and click **Fork**.
2. **Clone Your Fork**  
   - Clone the repository to your local machine:  
     ```bash
     git clone https://github.com/your-username/SDR-RPC.git
     ```
3. **Create a New Branch**  
   - Use a descriptive name for your branch:  
     ```bash
     git checkout -b feature/your-feature-name
     ```
4. **Write and Test Your Code**  
   - Follow the coding standards used in the project.
   - Ensure your code works by testing it thoroughly.
5. **Commit Your Changes**  
   - Write a clear and concise commit message:  
     ```bash
     git commit -m "Add a clear description of the changes"
     ```
6. **Push Your Changes**  
   - Push your branch to your forked repository:  
     ```bash
     git push origin feature/your-feature-name
     ```
7. **Create a Pull Request**  
   - Open a pull request from your branch to the `main` branch of the repository.
   - Include a detailed description of your changes.

#### Guidelines:
- Ensure your code adheres to the existing coding style.
- Document your changes if they impact functionality.
- Keep pull requests focused—address one issue or feature per PR.

---

### Improving Documentation
If you spot errors or outdated information in the documentation, feel free to submit corrections. This includes the `README.md`, `CONTRIBUTING.md`, and in-code comments.

---

## Development Environment Setup

To contribute effectively, set up your environment using the following steps:
1. Install [Visual Studio 2019](https://visualstudio.microsoft.com/vs/) or later.
2. Install the [.NET Framework 4.6 Developer Pack](https://dotnet.microsoft.com/download/dotnet-framework/thank-you/net46-developer-pack-offline-installer).
3. Download the [SDRSharp Plugin SDK](https://airspy.com/?ddownload=5944).
4. Clone the repository and open the `SDRSharpPlugin.DiscordRPC.sln` file in Visual Studio.

---

## Code of Conduct

By participating in this project, you agree to abide by the [Code of Conduct](CODE_OF_CONDUCT.md). Please treat others with respect and professionalism.

---

Thank you for contributing to SDR-RPC! If you have any questions, feel free to ask on the [issues page](https://github.com/EnderIce2/SDR-RPC/issues).
